@@ -50,8 +50,10 @@
 #include <functional>
 
 namespace QtWebEngineCore {
-class ProfileAdapter;
+class ContentBrowserClientQt;
 class CookieMonsterDelegateQt;
+class ProfileAdapter;
+class RestrictedCookieManagerQt;
 } // namespace QtWebEngineCore
 
 QT_BEGIN_NAMESPACE
@@ -84,8 +86,10 @@ Q_SIGNALS:
 
 private:
     explicit QWebEngineCookieStore(QObject *parent = Q_NULLPTR);
-    friend class QtWebEngineCore::ProfileAdapter;
+    friend class QtWebEngineCore::ContentBrowserClientQt;
     friend class QtWebEngineCore::CookieMonsterDelegateQt;
+    friend class QtWebEngineCore::ProfileAdapter;
+    friend class QtWebEngineCore::RestrictedCookieManagerQt;
     Q_DISABLE_COPY(QWebEngineCookieStore)
     Q_DECLARE_PRIVATE(QWebEngineCookieStore)
     QScopedPointer<QWebEngineCookieStorePrivate> d_ptr;
